# Reference

::: qmm.core.structure
    options:
      show_root_heading: true
      show_source: true
      summary: false
      members_order: source
      heading_level: 3
      show_bases: false
      show_signature_annotations: false
      docstring_section_style: table
      merge_init_into_class: false

::: qmm.core.stability
    options:
      show_root_heading: true
      show_source: true
      summary: false
      members_order: source
      heading_level: 3
      show_bases: false
      show_signature_annotations: false
      docstring_section_style: table
      merge_init_into_class: false

::: qmm.core.press
    options:
      show_root_heading: true
      show_source: true
      summary: false
      members_order: source
      heading_level: 3
      show_bases: false
      show_signature_annotations: false
      docstring_section_style: table
      merge_init_into_class: false

::: qmm.core.prediction
    options:
      show_root_heading: true
      show_source: true
      summary: false
      members_order: source
      heading_level: 3
      show_bases: false
      show_signature_annotations: false
      docstring_section_style: table
      merge_init_into_class: false

::: qmm.core.helper
    options:
      show_root_heading: true
      show_source: true
      summary: false
      members_order: source
      heading_level: 3
      show_bases: false
      show_signature_annotations: false
      docstring_section_style: table
      merge_init_into_class: false

## Extension module

::: qmm.extensions.senstability
    options:
      show_root_heading: true
      show_source: true
      summary: false
      members_order: source
      heading_level: 3
      show_bases: false
      show_signature_annotations: false
      docstring_section_style: table
      merge_init_into_class: false

::: qmm.extensions.life
    options:
      show_root_heading: true
      show_source: true
      summary: false
      members_order: source
      heading_level: 3
      show_bases: false
      show_signature_annotations: false
      docstring_section_style: table
      merge_init_into_class: false

::: qmm.extensions.paths
    options:
      show_root_heading: true
      show_source: true
      summary: false
      members_order: source
      heading_level: 3
      show_bases: false
      show_signature_annotations: false
      docstring_section_style: table
      merge_init_into_class: false

::: qmm.extensions.effects
    options:
      show_root_heading: true
      show_source: true
      summary: false
      members_order: source
      heading_level: 3
      show_bases: false
      show_signature_annotations: false
      docstring_section_style: table
      merge_init_into_class: false

::: qmm.extensions.indicators
    options:
      show_root_heading: true
      show_source: true
      summary: false
      members_order: source
      heading_level: 3
      show_bases: false
      show_signature_annotations: false
      docstring_section_style: table
      merge_init_into_class: false

::: qmm.extensions.validation
    options:
      show_root_heading: true
      show_source: true
      summary: false
      members_order: source
      heading_level: 3
      show_bases: false
      show_signature_annotations: false
      docstring_section_style: table
      merge_init_into_class: false